# Exported from OpenSSL 1.1.1a with ALL ciphers string. We use this lookup
# table because not everyone has an OpenSSL with that many (ancient) ciphers
# enabled.
_ciphersuite_lookup_table = {
    'TLS_AES_256_GCM_SHA384': {
        'id': 50336514,
        'name': 'TLS_AES_256_GCM_SHA384',
        'protocol': 'TLSv1.3',
        'description': 'TLS_AES_256_GCM_SHA384  TLSv1.3 Kx=any      Au=any  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'TLS_CHACHA20_POLY1305_SHA256': {
        'id': 50336515,
        'name': 'TLS_CHACHA20_POLY1305_SHA256',
        'protocol': 'TLSv1.3',
        'description': 'TLS_CHACHA20_POLY1305_SHA256 TLSv1.3 Kx=any      Au=any  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'TLS_AES_128_GCM_SHA256': {
        'id': 50336513,
        'name': 'TLS_AES_128_GCM_SHA256',
        'protocol': 'TLSv1.3',
        'description': 'TLS_AES_128_GCM_SHA256  TLSv1.3 Kx=any      Au=any  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'ECDHE-ECDSA-AES256-GCM-SHA384': {
        'id': 50380844,
        'name': 'ECDHE-ECDSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-GCM-SHA384': {
        'id': 50380848,
        'name': 'ECDHE-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-GCM-SHA384': {
        'id': 50331811,
        'name': 'DHE-DSS-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES256-GCM-SHA384 TLSv1.2 Kx=DH       Au=DSS  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-AES256-GCM-SHA384': {
        'id': 50331807,
        'name': 'DHE-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=DH       Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-CHACHA20-POLY1305': {
        'id': 50384041,
        'name': 'ECDHE-ECDSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CHACHA20-POLY1305 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CHACHA20-POLY1305': {
        'id': 50384040,
        'name': 'ECDHE-RSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CHACHA20-POLY1305 TLSv1.2 Kx=ECDH     Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CHACHA20-POLY1305': {
        'id': 50384042,
        'name': 'DHE-RSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CHACHA20-POLY1305 TLSv1.2 Kx=DH       Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-AES256-CCM8': {
        'id': 50380975,
        'name': 'ECDHE-ECDSA-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-CCM8 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ECDSA-AES256-CCM': {
        'id': 50380973,
        'name': 'ECDHE-ECDSA-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-CCM  TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'DHE-RSA-AES256-CCM8': {
        'id': 50380963,
        'name': 'DHE-RSA-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-CCM8     TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-CCM': {
        'id': 50380959,
        'name': 'DHE-RSA-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-CCM      TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-ARIA256-GCM-SHA384': {
        'id': 50380893,
        'name': 'ECDHE-ECDSA-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-ARIA256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ARIA256-GCM-SHA384': {
        'id': 50380897,
        'name': 'ECDHE-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ARIA256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-ARIA256-GCM-SHA384': {
        'id': 50380887,
        'name': 'DHE-DSS-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-ARIA256-GCM-SHA384 TLSv1.2 Kx=DH       Au=DSS  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-ARIA256-GCM-SHA384': {
        'id': 50380883,
        'name': 'DHE-RSA-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-ARIA256-GCM-SHA384 TLSv1.2 Kx=DH       Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ADH-AES256-GCM-SHA384': {
        'id': 50331815,
        'name': 'ADH-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES256-GCM-SHA384   TLSv1.2 Kx=DH       Au=None Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-GCM-SHA256': {
        'id': 50380843,
        'name': 'ECDHE-ECDSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-GCM-SHA256': {
        'id': 50380847,
        'name': 'ECDHE-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-GCM-SHA256': {
        'id': 50331810,
        'name': 'DHE-DSS-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES128-GCM-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-AES128-GCM-SHA256': {
        'id': 50331806,
        'name': 'DHE-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-AES128-CCM8': {
        'id': 50380974,
        'name': 'ECDHE-ECDSA-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-CCM8 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ECDSA-AES128-CCM': {
        'id': 50380972,
        'name': 'ECDHE-ECDSA-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-CCM  TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'DHE-RSA-AES128-CCM8': {
        'id': 50380962,
        'name': 'DHE-RSA-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-CCM8     TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-CCM': {
        'id': 50380958,
        'name': 'DHE-RSA-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-CCM      TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-ARIA128-GCM-SHA256': {
        'id': 50380892,
        'name': 'ECDHE-ECDSA-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-ARIA128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ARIA128-GCM-SHA256': {
        'id': 50380896,
        'name': 'ECDHE-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ARIA128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-ARIA128-GCM-SHA256': {
        'id': 50380886,
        'name': 'DHE-DSS-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-ARIA128-GCM-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-ARIA128-GCM-SHA256': {
        'id': 50380882,
        'name': 'DHE-RSA-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-ARIA128-GCM-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ADH-AES128-GCM-SHA256': {
        'id': 50331814,
        'name': 'ADH-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES128-GCM-SHA256   TLSv1.2 Kx=DH       Au=None Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES256-SHA384': {
        'id': 50380836,
        'name': 'ECDHE-ECDSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-SHA384': {
        'id': 50380840,
        'name': 'ECDHE-RSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES256-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-SHA256': {
        'id': 50331755,
        'name': 'DHE-RSA-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-SHA256   TLSv1.2 Kx=DH       Au=RSA  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-SHA256': {
        'id': 50331754,
        'name': 'DHE-DSS-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES256-SHA256   TLSv1.2 Kx=DH       Au=DSS  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ECDHE-ECDSA-CAMELLIA256-SHA384': {
        'id': 50380915,
        'name': 'ECDHE-ECDSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CAMELLIA256-SHA384': {
        'id': 50380919,
        'name': 'ECDHE-RSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CAMELLIA256-SHA256': {
        'id': 50331844,
        'name': 'DHE-RSA-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CAMELLIA256-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA256-SHA256': {
        'id': 50331843,
        'name': 'DHE-DSS-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-CAMELLIA256-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ADH-AES256-SHA256': {
        'id': 50331757,
        'name': 'ADH-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES256-SHA256       TLSv1.2 Kx=DH       Au=None Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA256-SHA256': {
        'id': 50331845,
        'name': 'ADH-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-CAMELLIA256-SHA256  TLSv1.2 Kx=DH       Au=None Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-SHA256': {
        'id': 50380835,
        'name': 'ECDHE-ECDSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-SHA256': {
        'id': 50380839,
        'name': 'ECDHE-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES128-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-SHA256': {
        'id': 50331751,
        'name': 'DHE-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-SHA256   TLSv1.2 Kx=DH       Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-SHA256': {
        'id': 50331712,
        'name': 'DHE-DSS-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES128-SHA256   TLSv1.2 Kx=DH       Au=DSS  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ECDHE-ECDSA-CAMELLIA128-SHA256': {
        'id': 50380914,
        'name': 'ECDHE-ECDSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CAMELLIA128-SHA256': {
        'id': 50380918,
        'name': 'ECDHE-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CAMELLIA128-SHA256': {
        'id': 50331838,
        'name': 'DHE-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA128-SHA256': {
        'id': 50331837,
        'name': 'DHE-DSS-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-CAMELLIA128-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ADH-AES128-SHA256': {
        'id': 50331756,
        'name': 'ADH-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES128-SHA256       TLSv1.2 Kx=DH       Au=None Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA128-SHA256': {
        'id': 50331839,
        'name': 'ADH-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-CAMELLIA128-SHA256  TLSv1.2 Kx=DH       Au=None Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES256-SHA': {
        'id': 50380810,
        'name': 'ECDHE-ECDSA-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-ECDSA-AES256-SHA  TLSv1 Kx=ECDH     Au=ECDSA Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-SHA': {
        'id': 50380820,
        'name': 'ECDHE-RSA-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-RSA-AES256-SHA    TLSv1 Kx=ECDH     Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-SHA': {
        'id': 50331705,
        'name': 'DHE-RSA-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-AES256-SHA      SSLv3 Kx=DH       Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-SHA': {
        'id': 50331704,
        'name': 'DHE-DSS-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-AES256-SHA      SSLv3 Kx=DH       Au=DSS  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-CAMELLIA256-SHA': {
        'id': 50331784,
        'name': 'DHE-RSA-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-CAMELLIA256-SHA SSLv3 Kx=DH       Au=RSA  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA256-SHA': {
        'id': 50331783,
        'name': 'DHE-DSS-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-CAMELLIA256-SHA SSLv3 Kx=DH       Au=DSS  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'AECDH-AES256-SHA': {
        'id': 50380825,
        'name': 'AECDH-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-AES256-SHA        TLSv1 Kx=ECDH     Au=None Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'},
    'ADH-AES256-SHA': {
        'id': 50331706,
        'name': 'ADH-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-AES256-SHA          SSLv3 Kx=DH       Au=None Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA256-SHA': {
        'id': 50331785,
        'name': 'ADH-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-CAMELLIA256-SHA     SSLv3 Kx=DH       Au=None Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-SHA': {
        'id': 50380809,
        'name': 'ECDHE-ECDSA-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-ECDSA-AES128-SHA  TLSv1 Kx=ECDH     Au=ECDSA Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-SHA': {
        'id': 50380819,
        'name': 'ECDHE-RSA-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-RSA-AES128-SHA    TLSv1 Kx=ECDH     Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-SHA': {
        'id': 50331699,
        'name': 'DHE-RSA-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-AES128-SHA      SSLv3 Kx=DH       Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-SHA': {
        'id': 50331698,
        'name': 'DHE-DSS-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-AES128-SHA      SSLv3 Kx=DH       Au=DSS  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-SEED-SHA': {
        'id': 50331802,
        'name': 'DHE-RSA-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-SEED-SHA        SSLv3 Kx=DH       Au=RSA  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-SEED-SHA': {
        'id': 50331801,
        'name': 'DHE-DSS-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-SEED-SHA        SSLv3 Kx=DH       Au=DSS  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-CAMELLIA128-SHA': {
        'id': 50331717,
        'name': 'DHE-RSA-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-CAMELLIA128-SHA SSLv3 Kx=DH       Au=RSA  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA128-SHA': {
        'id': 50331716,
        'name': 'DHE-DSS-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-CAMELLIA128-SHA SSLv3 Kx=DH       Au=DSS  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'AECDH-AES128-SHA': {
        'id': 50380824,
        'name': 'AECDH-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-AES128-SHA        TLSv1 Kx=ECDH     Au=None Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'},
    'ADH-AES128-SHA': {
        'id': 50331700,
        'name': 'ADH-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-AES128-SHA          SSLv3 Kx=DH       Au=None Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-SEED-SHA': {
        'id': 50331803,
        'name': 'ADH-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-SEED-SHA            SSLv3 Kx=DH       Au=None Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA128-SHA': {
        'id': 50331718,
        'name': 'ADH-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-CAMELLIA128-SHA     SSLv3 Kx=DH       Au=None Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'RSA-PSK-AES256-GCM-SHA384': {
        'id': 50331821,
        'name': 'RSA-PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-AES256-GCM-SHA384 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-GCM-SHA384': {
        'id': 50331819,
        'name': 'DHE-PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-GCM-SHA384 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CHACHA20-POLY1305': {
        'id': 50384046,
        'name': 'RSA-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CHACHA20-POLY1305': {
        'id': 50384045,
        'name': 'DHE-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CHACHA20-POLY1305': {
        'id': 50384044,
        'name': 'ECDHE-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=ECDHEPSK Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES256-CCM8': {
        'id': 50380971,
        'name': 'DHE-PSK-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-CCM8     TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES256-CCM': {
        'id': 50380967,
        'name': 'DHE-PSK-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-CCM      TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-ARIA256-GCM-SHA384': {
        'id': 50380911,
        'name': 'RSA-PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-ARIA256-GCM-SHA384 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-ARIA256-GCM-SHA384': {
        'id': 50380909,
        'name': 'DHE-PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-ARIA256-GCM-SHA384 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES256-GCM-SHA384': {
        'id': 50331805,
        'name': 'AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'AES256-GCM-SHA384       TLSv1.2 Kx=RSA      Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES256-CCM8': {
        'id': 50380961,
        'name': 'AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'AES256-CCM8             TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES256-CCM': {
        'id': 50380957,
        'name': 'AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'AES256-CCM              TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ARIA256-GCM-SHA384': {
        'id': 50380881,
        'name': 'ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ARIA256-GCM-SHA384      TLSv1.2 Kx=RSA      Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES256-GCM-SHA384': {
        'id': 50331817,
        'name': 'PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-GCM-SHA384   TLSv1.2 Kx=PSK      Au=PSK  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CHACHA20-POLY1305': {
        'id': 50384043,
        'name': 'PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'PSK-CHACHA20-POLY1305   TLSv1.2 Kx=PSK      Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CCM8': {
        'id': 50380969,
        'name': 'PSK-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-CCM8         TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CCM': {
        'id': 50380965,
        'name': 'PSK-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-CCM          TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-ARIA256-GCM-SHA384': {
        'id': 50380907,
        'name': 'PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'PSK-ARIA256-GCM-SHA384  TLSv1.2 Kx=PSK      Au=PSK  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES128-GCM-SHA256': {
        'id': 50331820,
        'name': 'RSA-PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-AES128-GCM-SHA256 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-GCM-SHA256': {
        'id': 50331818,
        'name': 'DHE-PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-GCM-SHA256 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES128-CCM8': {
        'id': 50380970,
        'name': 'DHE-PSK-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-CCM8     TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES128-CCM': {
        'id': 50380966,
        'name': 'DHE-PSK-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-CCM      TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-ARIA128-GCM-SHA256': {
        'id': 50380910,
        'name': 'RSA-PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-ARIA128-GCM-SHA256 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-ARIA128-GCM-SHA256': {
        'id': 50380908,
        'name': 'DHE-PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-ARIA128-GCM-SHA256 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES128-GCM-SHA256': {
        'id': 50331804,
        'name': 'AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES128-GCM-SHA256       TLSv1.2 Kx=RSA      Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-CCM8': {
        'id': 50380960,
        'name': 'AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'AES128-CCM8             TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-CCM': {
        'id': 50380956,
        'name': 'AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'AES128-CCM              TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ARIA128-GCM-SHA256': {
        'id': 50380880,
        'name': 'ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ARIA128-GCM-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES128-GCM-SHA256': {
        'id': 50331816,
        'name': 'PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-GCM-SHA256   TLSv1.2 Kx=PSK      Au=PSK  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CCM8': {
        'id': 50380968,
        'name': 'PSK-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-CCM8         TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CCM': {
        'id': 50380964,
        'name': 'PSK-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-CCM          TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-ARIA128-GCM-SHA256': {
        'id': 50380906,
        'name': 'PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'PSK-ARIA128-GCM-SHA256  TLSv1.2 Kx=PSK      Au=PSK  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'AES256-SHA256': {
        'id': 50331709,
        'name': 'AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES256-SHA256           TLSv1.2 Kx=RSA      Au=RSA  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA256-SHA256': {
        'id': 50331840,
        'name': 'CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'CAMELLIA256-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-SHA256': {
        'id': 50331708,
        'name': 'AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES128-SHA256           TLSv1.2 Kx=RSA      Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA128-SHA256': {
        'id': 50331834,
        'name': 'CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'CAMELLIA128-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ECDHE-PSK-AES256-CBC-SHA384': {
        'id': 50380856,
        'name': 'ECDHE-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES256-CBC-SHA384 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES256-CBC-SHA': {
        'id': 50380854,
        'name': 'ECDHE-PSK-AES256-CBC-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES256-CBC-SHA TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'SRP-DSS-AES-256-CBC-SHA': {
        'id': 50380834,
        'name': 'SRP-DSS-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-DSS-AES-256-CBC-SHA SSLv3 Kx=SRP      Au=DSS  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-dss'},
    'SRP-RSA-AES-256-CBC-SHA': {
        'id': 50380833,
        'name': 'SRP-RSA-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-RSA-AES-256-CBC-SHA SSLv3 Kx=SRP      Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-rsa'},
    'SRP-AES-256-CBC-SHA': {
        'id': 50380832,
        'name': 'SRP-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-AES-256-CBC-SHA     SSLv3 Kx=SRP      Au=SRP  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-srp'},
    'RSA-PSK-AES256-CBC-SHA384': {
        'id': 50331831,
        'name': 'RSA-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-AES256-CBC-SHA384 TLSv1 Kx=RSAPSK   Au=RSA  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-CBC-SHA384': {
        'id': 50331827,
        'name': 'DHE-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-AES256-CBC-SHA384 TLSv1 Kx=DHEPSK   Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES256-CBC-SHA': {
        'id': 50331797,
        'name': 'RSA-PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'RSA-PSK-AES256-CBC-SHA  SSLv3 Kx=RSAPSK   Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-CBC-SHA': {
        'id': 50331793,
        'name': 'DHE-PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-PSK-AES256-CBC-SHA  SSLv3 Kx=DHEPSK   Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CAMELLIA256-SHA384': {
        'id': 50380955,
        'name': 'ECDHE-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-CAMELLIA256-SHA384 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CAMELLIA256-SHA384': {
        'id': 50380953,
        'name': 'RSA-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-CAMELLIA256-SHA384 TLSv1 Kx=RSAPSK   Au=RSA  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CAMELLIA256-SHA384': {
        'id': 50380951,
        'name': 'DHE-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-CAMELLIA256-SHA384 TLSv1 Kx=DHEPSK   Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES256-SHA': {
        'id': 50331701,
        'name': 'AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'AES256-SHA              SSLv3 Kx=RSA      Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA256-SHA': {
        'id': 50331780,
        'name': 'CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'CAMELLIA256-SHA         SSLv3 Kx=RSA      Au=RSA  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES256-CBC-SHA384': {
        'id': 50331823,
        'name': 'PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'PSK-AES256-CBC-SHA384   TLSv1 Kx=PSK      Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CBC-SHA': {
        'id': 50331789,
        'name': 'PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'PSK-AES256-CBC-SHA      SSLv3 Kx=PSK      Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CAMELLIA256-SHA384': {
        'id': 50380949,
        'name': 'PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'PSK-CAMELLIA256-SHA384  TLSv1 Kx=PSK      Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES128-CBC-SHA256': {
        'id': 50380855,
        'name': 'ECDHE-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES128-CBC-SHA256 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES128-CBC-SHA': {
        'id': 50380853,
        'name': 'ECDHE-PSK-AES128-CBC-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES128-CBC-SHA TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'SRP-DSS-AES-128-CBC-SHA': {
        'id': 50380831,
        'name': 'SRP-DSS-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-DSS-AES-128-CBC-SHA SSLv3 Kx=SRP      Au=DSS  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-dss'},
    'SRP-RSA-AES-128-CBC-SHA': {
        'id': 50380830,
        'name': 'SRP-RSA-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-RSA-AES-128-CBC-SHA SSLv3 Kx=SRP      Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-rsa'},
    'SRP-AES-128-CBC-SHA': {
        'id': 50380829,
        'name': 'SRP-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-AES-128-CBC-SHA     SSLv3 Kx=SRP      Au=SRP  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-srp'},
    'RSA-PSK-AES128-CBC-SHA256': {
        'id': 50331830,
        'name': 'RSA-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-AES128-CBC-SHA256 TLSv1 Kx=RSAPSK   Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-CBC-SHA256': {
        'id': 50331826,
        'name': 'DHE-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-AES128-CBC-SHA256 TLSv1 Kx=DHEPSK   Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES128-CBC-SHA': {
        'id': 50331796,
        'name': 'RSA-PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'RSA-PSK-AES128-CBC-SHA  SSLv3 Kx=RSAPSK   Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-CBC-SHA': {
        'id': 50331792,
        'name': 'DHE-PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-PSK-AES128-CBC-SHA  SSLv3 Kx=DHEPSK   Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CAMELLIA128-SHA256': {
        'id': 50380954,
        'name': 'ECDHE-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-CAMELLIA128-SHA256 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CAMELLIA128-SHA256': {
        'id': 50380952,
        'name': 'RSA-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-CAMELLIA128-SHA256 TLSv1 Kx=RSAPSK   Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CAMELLIA128-SHA256': {
        'id': 50380950,
        'name': 'DHE-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-CAMELLIA128-SHA256 TLSv1 Kx=DHEPSK   Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES128-SHA': {
        'id': 50331695,
        'name': 'AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'AES128-SHA              SSLv3 Kx=RSA      Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'SEED-SHA': {
        'id': 50331798,
        'name': 'SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'SEED-SHA                SSLv3 Kx=RSA      Au=RSA  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA128-SHA': {
        'id': 50331713,
        'name': 'CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'CAMELLIA128-SHA         SSLv3 Kx=RSA      Au=RSA  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES128-CBC-SHA256': {
        'id': 50331822,
        'name': 'PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'PSK-AES128-CBC-SHA256   TLSv1 Kx=PSK      Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CBC-SHA': {
        'id': 50331788,
        'name': 'PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'PSK-AES128-CBC-SHA      SSLv3 Kx=PSK      Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CAMELLIA128-SHA256': {
        'id': 50380948,
        'name': 'PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'PSK-CAMELLIA128-SHA256  TLSv1 Kx=PSK      Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'AECDH-NULL-SHA': {
        'id': 50380821,
        'name': 'AECDH-NULL-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-NULL-SHA          TLSv1 Kx=ECDH     Au=None Enc=None      Mac=SHA1',
        'strength_bits': 0,
        'alg_bits': 0,
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'},

    # The following ciphers are defined in the testssh.sh provided OpenSSL
    # version. Those are mostly ancient ciphers or ciphers of draft versions of
    # TLS. Some of the names of 'kea', 'symmetric', etc. are made-up because
    # OpenSSL has no names assigned to them.

    'ECDHE-ECDSA-CHACHA20-POLY1305-OLD': {
        'id': 52244,
        'name': 'ECDHE-ECDSA-CHACHA20-POLY1305-OLD',
        'protocol': 'TLSv1.2',
        'description': '0xCC,0x14 - ECDHE-ECDSA-CHACHA20-POLY1305-OLD TLSv1.2 Kx=ECDH Au=ECDSA Enc=ChaCha20(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'chacha20-256',
        'digest': None,
        'kea': 'kx-ecdh',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CHACHA20-POLY1305-OLD': {
        'id': 52243,
        'name': 'ECDHE-RSA-CHACHA20-POLY1305-OLD',
        'protocol': 'TLSv1.2',
        'description': '0xCC,0x13 - ECDHE-RSA-CHACHA20-POLY1305-OLD TLSv1.2 Kx=ECDH Au=RSA Enc=ChaCha20(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'chacha20-256',
        'digest': None,
        'kea': 'kx-ecdh',
        'auth': 'auth-rsa'},
    'DHE-RSA-CHACHA20-POLY1305-OLD': {
        'id': 52245,
        'name': 'DHE-RSA-CHACHA20-POLY1305-OLD',
        'protocol': 'TLSv1.2',
        'description': '0xCC,0x15 - DHE-RSA-CHACHA20-POLY1305-OLD TLSv1.2 Kx=DH Au=RSA Enc=ChaCha20(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'chacha20-256',
        'digest': None,
        'kea': 'kx-dh',
        'auth': 'auth-rsa'},
    'DH-DSS-AES256-GCM-SHA384': {
        'id': 165,
        'name': 'DH-DSS-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xA5 - DH-DSS-AES256-GCM-SHA384 TLSv1.2 Kx=DH/DSS Au=DH Enc=AESGCM(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-AES256-GCM-SHA384': {
        'id': 161,
        'name': 'DH-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xA1 - DH-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=DH/RSA Au=DH Enc=AESGCM(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-RSA-AES256-SHA256': {
        'id': 105,
        'name': 'DH-RSA-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0x69 - DH-RSA-AES256-SHA256 TLSv1.2 Kx=DH/RSA Au=DH Enc=AES(256) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-AES256-SHA256': {
        'id': 104,
        'name': 'DH-DSS-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0x68 - DH-DSS-AES256-SHA256 TLSv1.2 Kx=DH/DSS Au=DH Enc=AES(256) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-AES256-SHA': {
        'id': 55,
        'name': 'DH-RSA-AES256-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x37 - DH-RSA-AES256-SHA SSLv3 Kx=DH/RSA Au=DH Enc=AES(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-AES256-SHA': {
        'id': 54,
        'name': 'DH-DSS-AES256-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x36 - DH-DSS-AES256-SHA SSLv3 Kx=DH/DSS Au=DH Enc=AES(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-CAMELLIA256-SHA256': {
        'id': 194,
        'name': 'DH-RSA-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xC2 - DH-RSA-CAMELLIA256-SHA256 TLSv1.2 Kx=DH/RSA Au=DH Enc=Camellia(256) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-CAMELLIA256-SHA256': {
        'id': 193,
        'name': 'DH-DSS-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xC1 - DH-DSS-CAMELLIA256-SHA256 TLSv1.2 Kx=DH/DSS Au=DH Enc=Camellia(256) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-CAMELLIA256-SHA': {
        'id': 134,
        'name': 'DH-RSA-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x86 - DH-RSA-CAMELLIA256-SHA SSLv3 Kx=DH/RSA Au=DH Enc=Camellia(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-CAMELLIA256-SHA': {
        'id': 133,
        'name': 'DH-DSS-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x85 - DH-DSS-CAMELLIA256-SHA SSLv3 Kx=DH/DSS Au=DH Enc=Camellia(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'ECDH-RSA-AES256-GCM-SHA384': {
        'id': 49202,
        'name': 'ECDH-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x32 - ECDH-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=AESGCM(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES256-GCM-SHA384': {
        'id': 49198,
        'name': 'ECDH-ECDSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x2E - ECDH-ECDSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=AESGCM(256) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-AES256-SHA384': {
        'id': 49194,
        'name': 'ECDH-RSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x2A - ECDH-RSA-AES256-SHA384 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=AES(256) Mac=SHA384',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES256-SHA384': {
        'id': 49190,
        'name': 'ECDH-ECDSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x26 - ECDH-ECDSA-AES256-SHA384 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=AES(256) Mac=SHA384',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-AES256-SHA': {
        'id': 49167,
        'name': 'ECDH-RSA-AES256-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x0F - ECDH-RSA-AES256-SHA SSLv3 Kx=ECDH/RSA Au=ECDH Enc=AES(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES256-SHA': {
        'id': 49157,
        'name': 'ECDH-ECDSA-AES256-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x05 - ECDH-ECDSA-AES256-SHA SSLv3 Kx=ECDH/ECDSA Au=ECDH Enc=AES(256) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-CAMELLIA256-SHA384': {
        'id': 49273,
        'name': 'ECDH-RSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x79 - ECDH-RSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=Camellia(256) Mac=SHA384',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-CAMELLIA256-SHA384': {
        'id': 49269,
        'name': 'ECDH-ECDSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x75 - ECDH-ECDSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=Camellia(256) Mac=SHA384',
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'DH-DSS-AES128-GCM-SHA256': {
        'id': 164,
        'name': 'DH-DSS-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xA4 - DH-DSS-AES128-GCM-SHA256 TLSv1.2 Kx=DH/DSS Au=DH Enc=AESGCM(128) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-AES128-GCM-SHA256': {
        'id': 160,
        'name': 'DH-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xA0 - DH-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=DH/RSA Au=DH Enc=AESGCM(128) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-RSA-AES128-SHA256': {
        'id': 63,
        'name': 'DH-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0x3F - DH-RSA-AES128-SHA256 TLSv1.2 Kx=DH/RSA Au=DH Enc=AES(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-AES128-SHA256': {
        'id': 62,
        'name': 'DH-DSS-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0x3E - DH-DSS-AES128-SHA256 TLSv1.2 Kx=DH/DSS Au=DH Enc=AES(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-AES128-SHA': {
        'id': 49,
        'name': 'DH-RSA-AES128-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x31 - DH-RSA-AES128-SHA SSLv3 Kx=DH/RSA Au=DH Enc=AES(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-AES128-SHA': {
        'id': 48,
        'name': 'DH-DSS-AES128-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x30 - DH-DSS-AES128-SHA SSLv3 Kx=DH/DSS Au=DH Enc=AES(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-CAMELLIA128-SHA256': {
        'id': 188,
        'name': 'DH-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xBC - DH-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=DH/RSA Au=DH Enc=Camellia(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-CAMELLIA128-SHA256': {
        'id': 187,
        'name': 'DH-DSS-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0xBB - DH-DSS-CAMELLIA128-SHA256 TLSv1.2 Kx=DH/DSS Au=DH Enc=Camellia(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-SEED-SHA': {
        'id': 152,
        'name': 'DH-RSA-SEED-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x98 - DH-RSA-SEED-SHA SSLv3 Kx=DH/RSA Au=DH Enc=SEED(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'seed-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-SEED-SHA': {
        'id': 151,
        'name': 'DH-DSS-SEED-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x97 - DH-DSS-SEED-SHA SSLv3 Kx=DH/DSS Au=DH Enc=SEED(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'seed-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'DH-RSA-CAMELLIA128-SHA': {
        'id': 67,
        'name': 'DH-RSA-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x43 - DH-RSA-CAMELLIA128-SHA SSLv3 Kx=DH/RSA Au=DH Enc=Camellia(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-CAMELLIA128-SHA': {
        'id': 66,
        'name': 'DH-DSS-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x42 - DH-DSS-CAMELLIA128-SHA SSLv3 Kx=DH/DSS Au=DH Enc=Camellia(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'ECDH-RSA-AES128-GCM-SHA256': {
        'id': 49201,
        'name': 'ECDH-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x31 - ECDH-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=AESGCM(128) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES128-GCM-SHA256': {
        'id': 49197,
        'name': 'ECDH-ECDSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x2D - ECDH-ECDSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=AESGCM(128) Mac=AEAD',
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-AES128-SHA256': {
        'id': 49193,
        'name': 'ECDH-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x29 - ECDH-RSA-AES128-SHA256 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=AES(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES128-SHA256': {
        'id': 49189,
        'name': 'ECDH-ECDSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x25 - ECDH-ECDSA-AES128-SHA256 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=AES(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-AES128-SHA': {
        'id': 49166,
        'name': 'ECDH-RSA-AES128-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x0E - ECDH-RSA-AES128-SHA SSLv3 Kx=ECDH/RSA Au=ECDH Enc=AES(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-AES128-SHA': {
        'id': 49156,
        'name': 'ECDH-ECDSA-AES128-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x04 - ECDH-ECDSA-AES128-SHA SSLv3 Kx=ECDH/ECDSA Au=ECDH Enc=AES(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'ECDH-RSA-CAMELLIA128-SHA256': {
        'id': 49272,
        'name': 'ECDH-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x78 - ECDH-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH/RSA Au=ECDH Enc=Camellia(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-CAMELLIA128-SHA256': {
        'id': 49268,
        'name': 'ECDH-ECDSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0xC0,0x74 - ECDH-ECDSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH/ECDSA Au=ECDH Enc=Camellia(128) Mac=SHA256',
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'IDEA-CBC-SHA': {
        'id': 7,
        'name': 'IDEA-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x07 - IDEA-CBC-SHA SSLv3 Kx=RSA Au=RSA Enc=IDEA(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'idea-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'IDEA-CBC-MD5': {
        'id': 327808,
        'name': 'IDEA-CBC-MD5',
        'protocol': 'SSLv2',
        'description': '0x05,0x00,0x80 - IDEA-CBC-MD5 SSLv2 Kx=RSA Au=RSA Enc=IDEA(128) Mac=MD5',
        'aead': False,
        'symmetric': 'idea-128-cbc',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'RC2-CBC-MD5': {
        'id': 196736,
        'name': 'RC2-CBC-MD5',
        'protocol': 'SSLv2',
        'description': '0x03,0x00,0x80 - RC2-CBC-MD5 SSLv2 Kx=RSA Au=RSA Enc=RC2(128) Mac=MD5',
        'aead': False,
        'symmetric': 'rc2-128',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ECDHE-RSA-RC4-SHA': {
        'id': 49169,
        'name': 'ECDHE-RSA-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x11 - ECDHE-RSA-RC4-SHA SSLv3 Kx=ECDH Au=RSA Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-RC4-SHA': {
        'id': 49159,
        'name': 'ECDHE-ECDSA-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x07 - ECDHE-ECDSA-RC4-SHA SSLv3 Kx=ECDH Au=ECDSA Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-ecdsa'},
    'DHE-DSS-RC4-SHA': {
        'id': 102,
        'name': 'DHE-DSS-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x66 - DHE-DSS-RC4-SHA SSLv3 Kx=DH Au=DSS Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-dss'},
    'AECDH-RC4-SHA': {
        'id': 49174,
        'name': 'AECDH-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x16 - AECDH-RC4-SHA SSLv3 Kx=ECDH Au=None Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-none'},
    'ADH-RC4-MD5': {
        'id': 24,
        'name': 'ADH-RC4-MD5',
        'protocol': 'SSLv3',
        'description': '0x00,0x18 - ADH-RC4-MD5 SSLv3 Kx=DH Au=None Enc=RC4(128) Mac=MD5',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'md5',
        'kea': 'kx-dh',
        'auth': 'auth-none'},
    'ECDH-RSA-RC4-SHA': {
        'id': 49164,
        'name': 'ECDH-RSA-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x0C - ECDH-RSA-RC4-SHA SSLv3 Kx=ECDH/RSA Au=ECDH Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-RC4-SHA': {
        'id': 49154,
        'name': 'ECDH-ECDSA-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x02 - ECDH-ECDSA-RC4-SHA SSLv3 Kx=ECDH/ECDSA Au=ECDH Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'RC4-SHA': {
        'id': 5,
        'name': 'RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x05 - RC4-SHA SSLv3 Kx=RSA Au=RSA Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'RC4-MD5': {
        'id': 65664,
        'name': 'RC4-MD5',
        'protocol': 'SSLv2',
        'description': '0x01,0x00,0x80 - RC4-MD5 SSLv2 Kx=RSA Au=RSA Enc=RC4(128) Mac=MD5',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'RSA-PSK-RC4-SHA': {
        'id': 146,
        'name': 'RSA-PSK-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x92 - RSA-PSK-RC4-SHA SSLv3 Kx=RSAPSK Au=RSA Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'PSK-RC4-SHA': {
        'id': 138,
        'name': 'PSK-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x8A - PSK-RC4-SHA SSLv3 Kx=PSK Au=PSK Enc=RC4(128) Mac=SHA1',
        'aead': False,
        'symmetric': 'rc4-128',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'ECDHE-RSA-DES-CBC3-SHA': {
        'id': 49170,
        'name': 'ECDHE-RSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x12 - ECDHE-RSA-DES-CBC3-SHA SSLv3 Kx=ECDH Au=RSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-DES-CBC3-SHA': {
        'id': 49160,
        'name': 'ECDHE-ECDSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x08 - ECDHE-ECDSA-DES-CBC3-SHA SSLv3 Kx=ECDH Au=ECDSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-ecdsa'},
    'SRP-DSS-3DES-EDE-CBC-SHA': {
        'id': 49180,
        'name': 'SRP-DSS-3DES-EDE-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x1C - SRP-DSS-3DES-EDE-CBC-SHA SSLv3 Kx=SRP Au=DSS Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-dss'},
    'SRP-RSA-3DES-EDE-CBC-SHA': {
        'id': 49179,
        'name': 'SRP-RSA-3DES-EDE-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x1B - SRP-RSA-3DES-EDE-CBC-SHA SSLv3 Kx=SRP Au=RSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-rsa'},
    'SRP-3DES-EDE-CBC-SHA': {
        'id': 49178,
        'name': 'SRP-3DES-EDE-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x1A - SRP-3DES-EDE-CBC-SHA SSLv3 Kx=SRP Au=SRP Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-srp'},
    'EDH-RSA-DES-CBC3-SHA': {
        'id': 22,
        'name': 'EDH-RSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x16 - EDH-RSA-DES-CBC3-SHA SSLv3 Kx=DH Au=RSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-rsa'},
    'EDH-DSS-DES-CBC3-SHA': {
        'id': 19,
        'name': 'EDH-DSS-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x13 - EDH-DSS-DES-CBC3-SHA SSLv3 Kx=DH Au=DSS Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-dss'},
    'DH-RSA-DES-CBC3-SHA': {
        'id': 16,
        'name': 'DH-RSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x10 - DH-RSA-DES-CBC3-SHA SSLv3 Kx=DH/RSA Au=DH Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-DES-CBC3-SHA': {
        'id': 13,
        'name': 'DH-DSS-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0D - DH-DSS-DES-CBC3-SHA SSLv3 Kx=DH/DSS Au=DH Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'AECDH-DES-CBC3-SHA': {
        'id': 49175,
        'name': 'AECDH-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x17 - AECDH-DES-CBC3-SHA SSLv3 Kx=ECDH Au=None Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-none'},
    'ADH-DES-CBC3-SHA': {
        'id': 27,
        'name': 'ADH-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x1B - ADH-DES-CBC3-SHA SSLv3 Kx=DH Au=None Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-none'},
    'ECDH-RSA-DES-CBC3-SHA': {
        'id': 49165,
        'name': 'ECDH-RSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x0D - ECDH-RSA-DES-CBC3-SHA SSLv3 Kx=ECDH/RSA Au=ECDH Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-DES-CBC3-SHA': {
        'id': 49155,
        'name': 'ECDH-ECDSA-DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x03 - ECDH-ECDSA-DES-CBC3-SHA SSLv3 Kx=ECDH/ECDSA Au=ECDH Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'DES-CBC3-SHA': {
        'id': 10,
        'name': 'DES-CBC3-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0A - DES-CBC3-SHA SSLv3 Kx=RSA Au=RSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'DES-CBC3-MD5': {
        'id': 458944,
        'name': 'DES-CBC3-MD5',
        'protocol': 'SSLv2',
        'description': '0x07,0x00,0xC0 - DES-CBC3-MD5 SSLv2 Kx=RSA Au=RSA Enc=3DES(168) Mac=MD5',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'RSA-PSK-3DES-EDE-CBC-SHA': {
        'id': 147,
        'name': 'RSA-PSK-3DES-EDE-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x93 - RSA-PSK-3DES-EDE-CBC-SHA SSLv3 Kx=RSAPSK Au=RSA Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'PSK-3DES-EDE-CBC-SHA': {
        'id': 139,
        'name': 'PSK-3DES-EDE-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x8B - PSK-3DES-EDE-CBC-SHA SSLv3 Kx=PSK Au=PSK Enc=3DES(168) Mac=SHA1',
        'aead': False,
        'symmetric': '3des-168',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'RC4-64-MD5': {
        'id': 524416,
        'name': 'RC4-64-MD5',
        'protocol': 'SSLv2',
        'description': '0x08,0x00,0x80 - RC4-64-MD5 SSLv2 Kx=RSA Au=RSA Enc=RC4(64) Mac=MD5',
        'aead': False,
        'symmetric': 'rc4-64',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'EXP1024-DHE-DSS-DES-CBC-SHA': {
        'id': 99,
        'name': 'EXP1024-DHE-DSS-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x63 - EXP1024-DHE-DSS-DES-CBC-SHA SSLv3 Kx=DH(1024) Au=DSS Enc=DES(56) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-1024',
        'auth': 'auth-dss'},
    'EDH-RSA-DES-CBC-SHA': {
        'id': 21,
        'name': 'EDH-RSA-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x15 - EDH-RSA-DES-CBC-SHA SSLv3 Kx=DH Au=RSA Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-rsa'},
    'EDH-DSS-DES-CBC-SHA': {
        'id': 18,
        'name': 'EDH-DSS-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x12 - EDH-DSS-DES-CBC-SHA SSLv3 Kx=DH Au=DSS Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-dss'},
    'DH-RSA-DES-CBC-SHA': {
        'id': 15,
        'name': 'DH-RSA-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0F - DH-RSA-DES-CBC-SHA SSLv3 Kx=DH/RSA Au=DH Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'DH-DSS-DES-CBC-SHA': {
        'id': 12,
        'name': 'DH-DSS-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0C - DH-DSS-DES-CBC-SHA SSLv3 Kx=DH/DSS Au=DH Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'ADH-DES-CBC-SHA': {
        'id': 26,
        'name': 'ADH-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x1A - ADH-DES-CBC-SHA SSLv3 Kx=DH Au=None Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh',
        'auth': 'auth-none'},
    'EXP1024-DES-CBC-SHA': {
        'id': 98,
        'name': 'EXP1024-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x62 - EXP1024-DES-CBC-SHA SSLv3 Kx=RSA(1024) Au=RSA Enc=DES(56) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-1024',
        'auth': 'auth-rsa'},
    'DES-CBC-SHA': {
        'id': 9,
        'name': 'DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x09 - DES-CBC-SHA SSLv3 Kx=RSA Au=RSA Enc=DES(56) Mac=SHA1',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'EXP1024-RC2-CBC-MD5': {
        'id': 97,
        'name': 'EXP1024-RC2-CBC-MD5',
        'protocol': 'SSLv3',
        'description': '0x00,0x61 - EXP1024-RC2-CBC-MD5 SSLv3 Kx=RSA(1024) Au=RSA Enc=RC2(56) Mac=MD5 export',
        'aead': False,
        'symmetric': 'rc2-56',
        'digest': 'md5',
        'kea': 'kx-rsa-1024',
        'auth': 'auth-rsa'},
    'DES-CBC-MD5': {
        'id': 393280,
        'name': 'DES-CBC-MD5',
        'protocol': 'SSLv2',
        'description': '0x06,0x00,0x40 - DES-CBC-MD5 SSLv2 Kx=RSA Au=RSA Enc=DES(56) Mac=MD5',
        'aead': False,
        'symmetric': 'des-56-cbc',
        'digest': 'md5',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'EXP1024-DHE-DSS-RC4-SHA': {
        'id': 101,
        'name': 'EXP1024-DHE-DSS-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x65 - EXP1024-DHE-DSS-RC4-SHA SSLv3 Kx=DH(1024) Au=DSS Enc=RC4(56) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'rc4-56',
        'digest': 'sha1',
        'kea': 'kx-dh-1024',
        'auth': 'auth-dss'},
    'EXP1024-RC4-SHA': {
        'id': 100,
        'name': 'EXP1024-RC4-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x64 - EXP1024-RC4-SHA SSLv3 Kx=RSA(1024) Au=RSA Enc=RC4(56) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'rc4-56',
        'digest': 'sha1',
        'kea': 'kx-rsa-1024',
        'auth': 'auth-rsa'},
    'EXP1024-RC4-MD5': {
        'id': 96,
        'name': 'EXP1024-RC4-MD5',
        'protocol': 'SSLv3',
        'description': '0x00,0x60 - EXP1024-RC4-MD5 SSLv3 Kx=RSA(1024) Au=RSA Enc=RC4(56) Mac=MD5 export',
        'aead': False,
        'symmetric': 'rc4-56',
        'digest': 'md5',
        'kea': 'kx-rsa-1024',
        'auth': 'auth-rsa'},
    'EXP-EDH-RSA-DES-CBC-SHA': {
        'id': 20,
        'name': 'EXP-EDH-RSA-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x14 - EXP-EDH-RSA-DES-CBC-SHA SSLv3 Kx=DH(512) Au=RSA Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-512',
        'auth': 'auth-rsa'},
    'EXP-EDH-DSS-DES-CBC-SHA': {
        'id': 17,
        'name': 'EXP-EDH-DSS-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x11 - EXP-EDH-DSS-DES-CBC-SHA SSLv3 Kx=DH(512) Au=DSS Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-512',
        'auth': 'auth-dss'},
    'EXP-DH-RSA-DES-CBC-SHA': {
        'id': 14,
        'name': 'EXP-DH-RSA-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0E - EXP-DH-RSA-DES-CBC-SHA SSLv3 Kx=DH/RSA Au=DH Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-rsa',
        'auth': 'auth-dh'},
    'EXP-DH-DSS-DES-CBC-SHA': {
        'id': 11,
        'name': 'EXP-DH-DSS-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x0B - EXP-DH-DSS-DES-CBC-SHA SSLv3 Kx=DH/DSS Au=DH Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-dss',
        'auth': 'auth-dh'},
    'EXP-ADH-DES-CBC-SHA': {
        'id': 25,
        'name': 'EXP-ADH-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x19 - EXP-ADH-DES-CBC-SHA SSLv3 Kx=DH(512) Au=None Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-dh-512',
        'auth': 'auth-none'},
    'EXP-DES-CBC-SHA': {
        'id': 8,
        'name': 'EXP-DES-CBC-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x08 - EXP-DES-CBC-SHA SSLv3 Kx=RSA(512) Au=RSA Enc=DES(40) Mac=SHA1 export',
        'aead': False,
        'symmetric': 'des-40-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-512',
        'auth': 'auth-rsa'},
    'EXP-RC2-CBC-MD5': {
        'id': 262272,
        'name': 'EXP-RC2-CBC-MD5',
        'protocol': 'SSLv2',
        'description': '0x04,0x00,0x80 - EXP-RC2-CBC-MD5 SSLv2 Kx=RSA(512) Au=RSA Enc=RC2(40) Mac=MD5 export',
        'aead': False,
        'symmetric': 'rc2-40',
        'digest': 'md5',
        'kea': 'kx-rsa-512',
        'auth': 'auth-rsa'},
    'EXP-ADH-RC4-MD5': {
        'id': 23,
        'name': 'EXP-ADH-RC4-MD5',
        'protocol': 'SSLv3',
        'description': '0x00,0x17 - EXP-ADH-RC4-MD5 SSLv3 Kx=DH(512) Au=None Enc=RC4(40) Mac=MD5 export',
        'aead': False,
        'symmetric': 'rc4-40',
        'digest': 'md5',
        'kea': 'kx-dh-512',
        'auth': 'auth-none'},
    'EXP-RC4-MD5': {
        'id': 131200,
        'name': 'EXP-RC4-MD5',
        'protocol': 'SSLv2',
        'description': '0x02,0x00,0x80 - EXP-RC4-MD5 SSLv2 Kx=RSA(512) Au=RSA Enc=RC4(40) Mac=MD5 export',
        'aead': False,
        'symmetric': 'rc4-40',
        'digest': 'md5',
        'kea': 'kx-rsa-512',
        'auth': 'auth-rsa'},
    'ECDHE-RSA-NULL-SHA': {
        'id': 49168,
        'name': 'ECDHE-RSA-NULL-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x10 - ECDHE-RSA-NULL-SHA SSLv3 Kx=ECDH Au=RSA Enc=None Mac=SHA1',
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-NULL-SHA': {
        'id': 49158,
        'name': 'ECDHE-ECDSA-NULL-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x06 - ECDHE-ECDSA-NULL-SHA SSLv3 Kx=ECDH Au=ECDSA Enc=None Mac=SHA1',
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdh',
        'auth': 'auth-ecdsa'},
    'ECDH-RSA-NULL-SHA': {
        'id': 49163,
        'name': 'ECDH-RSA-NULL-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x0B - ECDH-RSA-NULL-SHA SSLv3 Kx=ECDH/RSA Au=ECDH Enc=None Mac=SHA1',
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdh-rsa',
        'auth': 'auth-ecdh'},
    'ECDH-ECDSA-NULL-SHA': {
        'id': 49153,
        'name': 'ECDH-ECDSA-NULL-SHA',
        'protocol': 'SSLv3',
        'description': '0xC0,0x01 - ECDH-ECDSA-NULL-SHA SSLv3 Kx=ECDH/ECDSA Au=ECDH Enc=None Mac=SHA1',
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdh-ecdsa',
        'auth': 'auth-ecdh'},
    'NULL-SHA256': {
        'id': 59,
        'name': 'NULL-SHA256',
        'protocol': 'TLSv1.2',
        'description': '0x00,0x3B - NULL-SHA256 TLSv1.2 Kx=RSA Au=RSA Enc=None Mac=SHA256',
        'aead': False,
        'symmetric': None,
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'NULL-SHA': {
        'id': 2,
        'name': 'NULL-SHA',
        'protocol': 'SSLv3',
        'description': '0x00,0x02 - NULL-SHA SSLv3 Kx=RSA Au=RSA Enc=None Mac=SHA1',
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'NULL-MD5': {
        'id': 0,
        'name': 'NULL-MD5',
        'protocol': 'SSLv2',
        'description': '0x00,0x00,0x00 - NULL-MD5 SSLv2 Kx=RSA(512) Au=RSA Enc=None Mac=MD5',
        'aead': False,
        'symmetric': None,
        'digest': 'md5',
        'kea': 'kx-rsa-512',
        'auth': 'auth-rsa'}}


def lookup_ciphersuite(ciphersuite_name):
    try:
        return _ciphersuite_lookup_table[ciphersuite_name]
    except KeyError:
        # We hopefully have all ciphersuites in this file, so this should
        # never happen. If it happens, report a bug with the ciphersuite
        # that is not defined.
        raise ValueError('Cannot find your ciphersuite: ' + ciphersuite_name)



import json
import re
from pathlib import Path

from tldextract import TLDExtract

TLDEXTRACT_CACHE_FILE = Path('tldextract/.tld_set')


class JavaScriptError(Exception):
    pass


class scripts_disabled:
    def __init__(self, tab, options):
        self._tab = tab
        self._options = options

    def __enter__(self):
        # On pages that already have javascript disabled, do nothing.
        if not self._options['disable_javascript']:
            self._tab.Emulation.setScriptExecutionDisabled(value=True)

    def __exit__(self, exc_type, exc_val, exc_tb):
        # On pages that already have javascript disabled, do nothing.
        if not self._options['disable_javascript']:
            self._tab.Emulation.setScriptExecutionDisabled(value=False)


def camelcase_to_underscore(text):
    return re.sub('[A-Z]', lambda m: '_' + m.group(0).lower(), text)


def javascript_evaluate(tab, js_expr):
    js_expr = _javascript_stringify(js_expr)
    result = tab.Runtime.evaluate(expression=js_expr)['result']
    if result.get('subtype') == 'error':
        error_type = result.get('className', 'UnknownError')
        error_description = result.get('description', 'No description')
        raise JavaScriptError('{}: {}'.format(error_type, error_description))
    elif result.get('type') == 'string':
        return json.loads(result.get('value', 'null'))
    else:
        raise RuntimeError('Unexpected response from Chrome: {}'.format(result))


def _javascript_stringify(js_expr):
    return """
    (function() {
        var __oldToJSON = Array.prototype.toJSON;
        delete Array.prototype.toJSON;
        var __returnValue = JSON.stringify(%s);
        if (typeof(__oldToJSON) !== undefined) {
            Array.prototype.toJSON = __oldToJSON;
        }
        return __returnValue;
    })();
    """ % js_expr.strip()


parse_domain = TLDExtract()



from binascii import hexlify
from datetime import datetime

from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.asymmetric.dsa import DSAPublicKey
from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePublicKey
from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
from cryptography.x509 import load_der_x509_certificate

from privacyscanner.utils.cipherinfo import lookup_ciphersuite


def get_certificate_info(cert_der):
    # See https://cryptography.io/en/latest/x509/reference/#cryptography.x509.Certificate
    cert = load_der_x509_certificate(cert_der, backend=default_backend())
    public_key = cert.public_key()
    key_info = {'size': public_key.key_size}
    if isinstance(public_key, RSAPublicKey):
        key_type = 'RSA'
    elif isinstance(public_key, DSAPublicKey):
        key_type = 'DSA'
    elif isinstance(public_key, EllipticCurvePublicKey):
        key_type = 'ECC'
        key_info['curve'] = public_key.curve.name
    else:
        raise ValueError('Invalid key type.')
    key_info['type'] = key_type
    return {
        'version': cert.version.name,
        'fingerprint_sha256': hexlify(cert.fingerprint(hashes.SHA256())).decode(),
        'serial_number': cert.serial_number,
        'not_valid_before': cert.not_valid_before.timestamp(),
        'not_valid_after': cert.not_valid_after.timestamp(),
        'issuer':  {attr.oid._name: attr.value for attr in cert.issuer},
        'subject': {attr.oid._name: attr.value for attr in cert.subject},
        'key': key_info,
        'is_expired': datetime.now() > cert.not_valid_after
    }
    # TODO: Add extensions


def get_cipher_info(cipher_tuple):
    cipher_string, protocol, bits = cipher_tuple
    return _build_cipher_info(lookup_ciphersuite(cipher_string), protocol)


def _build_cipher_info(cipher_info, protocol):
    if 'symmetric' not in cipher_info:
        raise RuntimeError('OpenSSL 1.1 is required. Even Debian 9 has it.')
    cipher = cipher_info['symmetric'].replace('-', '_').upper()
    params = _parse_openssl_description(cipher_info['description'])
    key_exchange = None
    if 'Kx' in params:
        key_exchange = params['Kx']
    if 'Au':
        key_exchange += '_' + params['Au']
    # Unfortunately, OpenSSL does not provide any information about the group.
    key_exchange_group = None
    mac = None
    if 'mac' in params:
        # AHEAD ciphers do not have a MAC
        mac = params['mac'] if params['mac'] != 'AHEAD' else None
    return {
        'cipher': cipher,
        'key_exchange': key_exchange,
        'key_exchange_group': None,
        'mac': mac,
        'protocol': protocol.replace('TLSv', 'TLS '),
    }


def _parse_openssl_description(description):
    parts = description.split()
    result = {}
    for part in parts:
        if '=' in part:
            key, value = part.split('=', 1)
            result[key] = value
    result['name'] = parts[0]
    result['protocol'] = parts[1]
    return result



from privacyscanner.scanmodules.chromedevtools.extractors.base import Extractor


class RedirectChainExtractor(Extractor):
    def extract_information(self):
        response_chain = []
        for request in self.page.document_request_log:
            response_chain += self.page.get_response_chain_by_id(request['requestId'])
        self.result['redirect_chain'] = [response['url'] for response in response_chain]



class Result(object):
    def __init__(self, result_dict, file_handler):
        self._result_dict = result_dict
        self._file_handler = file_handler
        self._updated_keys = set()

    def add_debug_file(self, filename, contents=None):
        self._file_handler.add_file(
            filename, self._get_file_contents(filename, contents), debug=True)

    def add_file(self, filename, contents):
        self._file_handler.add_file(
            filename, self._get_file_contents(filename, contents), debug=False)

    def _get_file_contents(self, filename, contents=None):
        if contents is None:
            with open(filename, 'rb') as f:
                return f.read()
        if hasattr(contents, 'read'):
            contents = contents.read()
        return contents

    def __getitem__(self, key):
        return self._result_dict[key]

    def __setitem__(self, key, value):
        self.mark_dirty(key)
        self._result_dict[key] = value

    def __contains__(self, key):
        return key in self._result_dict

    def get(self, key, d=None):
        return self._result_dict.get(key, d)

    def keys(self):
        return self._result_dict.keys()

    def values(self):
        return self._result_dict.items()

    def items(self):
        return self._result_dict.items()

    def update(self, d, **kwargs):
        if isinstance(d, dict):
            for key in d:
                self.mark_dirty(key)
        else:
            for key, _value in d:
                self.mark_dirty(key)
        for key in kwargs:
            self.mark_dirty(key)
        return self._result_dict.update(d, **kwargs)

    def setdefault(self, key, d):
        self.mark_dirty(key)
        return self._result_dict.setdefault(key, d)

    def mark_dirty(self, key):
        self._updated_keys.add(key)

    def get_updates(self):
        return {key: self._result_dict[key] for key in self._updated_keys}

    def get_results(self):
        return self._result_dict



class Extractor:
    def __init__(self, page, result, logger, options):
        self.result = result
        self.logger = logger
        self.options = options
        self.page = page

    def extract_information(self):
        raise NotImplementedError('You have to implement extract_information() in {}'.format(
            self.__class__.__name__))

    def receive_log(self, log_type, message, call_stack):
        pass

    def register_javascript(self):
        pass
